@@ -1,18 +1,55 @@
-#[doc = "Reader of register DRVCTRL"]
-pub type R = crate::R<u32, super::DRVCTRL>;
-#[doc = "Writer for register DRVCTRL"]
-pub type W = crate::W<u32, super::DRVCTRL>;
-#[doc = "Register DRVCTRL `reset()`'s with value 0"]
-impl crate::ResetValue for super::DRVCTRL {
-    type Type = u32;
+#[doc = "Register `DRVCTRL` reader"]
+pub struct R(crate::R<DRVCTRL_SPEC>);
+impl core::ops::Deref for R {
+    type Target = crate::R<DRVCTRL_SPEC>;
     #[inline(always)]
-    fn reset_value() -> Self::Type {
-        0
+    fn deref(&self) -> &Self::Target {
+        &self.0
     }
 }
-#[doc = "Reader of field `NRE0`"]
-pub type NRE0_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `NRE0`"]
+impl From<crate::R<DRVCTRL_SPEC>> for R {
+    #[inline(always)]
+    fn from(reader: crate::R<DRVCTRL_SPEC>) -> Self {
+        R(reader)
+    }
+}
+#[doc = "Register `DRVCTRL` writer"]
+pub struct W(crate::W<DRVCTRL_SPEC>);
+impl core::ops::Deref for W {
+    type Target = crate::W<DRVCTRL_SPEC>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+impl core::ops::DerefMut for W {
+    #[inline(always)]
+    fn deref_mut(&mut self) -> &mut Self::Target {
+        &mut self.0
+    }
+}
+impl From<crate::W<DRVCTRL_SPEC>> for W {
+    #[inline(always)]
+    fn from(writer: crate::W<DRVCTRL_SPEC>) -> Self {
+        W(writer)
+    }
+}
+#[doc = "Field `NRE0` reader - Non-Recoverable State 0 Output Enable"]
+pub struct NRE0_R(crate::FieldReader<bool, bool>);
+impl NRE0_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        NRE0_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for NRE0_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `NRE0` writer - Non-Recoverable State 0 Output Enable"]
 pub struct NRE0_W<'a> {
     w: &'a mut W,
 }
@@ -30,13 +67,26 @@ impl<'a> NRE0_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !0x01) | ((value as u32) & 0x01);
+        self.w.bits = (self.w.bits & !0x01) | (value as u32 & 0x01);
         self.w
     }
 }
-#[doc = "Reader of field `NRE1`"]
-pub type NRE1_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `NRE1`"]
+#[doc = "Field `NRE1` reader - Non-Recoverable State 1 Output Enable"]
+pub struct NRE1_R(crate::FieldReader<bool, bool>);
+impl NRE1_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        NRE1_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for NRE1_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `NRE1` writer - Non-Recoverable State 1 Output Enable"]
 pub struct NRE1_W<'a> {
     w: &'a mut W,
 }
@@ -54,13 +104,26 @@ impl<'a> NRE1_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 1)) | (((value as u32) & 0x01) << 1);
+        self.w.bits = (self.w.bits & !(0x01 << 1)) | ((value as u32 & 0x01) << 1);
         self.w
     }
 }
-#[doc = "Reader of field `NRE2`"]
-pub type NRE2_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `NRE2`"]
+#[doc = "Field `NRE2` reader - Non-Recoverable State 2 Output Enable"]
+pub struct NRE2_R(crate::FieldReader<bool, bool>);
+impl NRE2_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        NRE2_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for NRE2_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `NRE2` writer - Non-Recoverable State 2 Output Enable"]
 pub struct NRE2_W<'a> {
     w: &'a mut W,
 }
@@ -78,13 +141,26 @@ impl<'a> NRE2_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 2)) | (((value as u32) & 0x01) << 2);
+        self.w.bits = (self.w.bits & !(0x01 << 2)) | ((value as u32 & 0x01) << 2);
         self.w
     }
 }
-#[doc = "Reader of field `NRE3`"]
-pub type NRE3_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `NRE3`"]
+#[doc = "Field `NRE3` reader - Non-Recoverable State 3 Output Enable"]
+pub struct NRE3_R(crate::FieldReader<bool, bool>);
+impl NRE3_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        NRE3_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for NRE3_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `NRE3` writer - Non-Recoverable State 3 Output Enable"]
 pub struct NRE3_W<'a> {
     w: &'a mut W,
 }
@@ -102,13 +178,26 @@ impl<'a> NRE3_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 3)) | (((value as u32) & 0x01) << 3);
+        self.w.bits = (self.w.bits & !(0x01 << 3)) | ((value as u32 & 0x01) << 3);
         self.w
     }
 }
-#[doc = "Reader of field `NRE4`"]
-pub type NRE4_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `NRE4`"]
+#[doc = "Field `NRE4` reader - Non-Recoverable State 4 Output Enable"]
+pub struct NRE4_R(crate::FieldReader<bool, bool>);
+impl NRE4_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        NRE4_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for NRE4_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `NRE4` writer - Non-Recoverable State 4 Output Enable"]
 pub struct NRE4_W<'a> {
     w: &'a mut W,
 }
@@ -126,13 +215,26 @@ impl<'a> NRE4_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 4)) | (((value as u32) & 0x01) << 4);
+        self.w.bits = (self.w.bits & !(0x01 << 4)) | ((value as u32 & 0x01) << 4);
         self.w
     }
 }
-#[doc = "Reader of field `NRE5`"]
-pub type NRE5_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `NRE5`"]
+#[doc = "Field `NRE5` reader - Non-Recoverable State 5 Output Enable"]
+pub struct NRE5_R(crate::FieldReader<bool, bool>);
+impl NRE5_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        NRE5_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for NRE5_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `NRE5` writer - Non-Recoverable State 5 Output Enable"]
 pub struct NRE5_W<'a> {
     w: &'a mut W,
 }
@@ -150,13 +252,26 @@ impl<'a> NRE5_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 5)) | (((value as u32) & 0x01) << 5);
+        self.w.bits = (self.w.bits & !(0x01 << 5)) | ((value as u32 & 0x01) << 5);
         self.w
     }
 }
-#[doc = "Reader of field `NRE6`"]
-pub type NRE6_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `NRE6`"]
+#[doc = "Field `NRE6` reader - Non-Recoverable State 6 Output Enable"]
+pub struct NRE6_R(crate::FieldReader<bool, bool>);
+impl NRE6_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        NRE6_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for NRE6_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `NRE6` writer - Non-Recoverable State 6 Output Enable"]
 pub struct NRE6_W<'a> {
     w: &'a mut W,
 }
@@ -174,13 +289,26 @@ impl<'a> NRE6_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 6)) | (((value as u32) & 0x01) << 6);
+        self.w.bits = (self.w.bits & !(0x01 << 6)) | ((value as u32 & 0x01) << 6);
         self.w
     }
 }
-#[doc = "Reader of field `NRE7`"]
-pub type NRE7_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `NRE7`"]
+#[doc = "Field `NRE7` reader - Non-Recoverable State 7 Output Enable"]
+pub struct NRE7_R(crate::FieldReader<bool, bool>);
+impl NRE7_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        NRE7_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for NRE7_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `NRE7` writer - Non-Recoverable State 7 Output Enable"]
 pub struct NRE7_W<'a> {
     w: &'a mut W,
 }
@@ -198,13 +326,26 @@ impl<'a> NRE7_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 7)) | (((value as u32) & 0x01) << 7);
+        self.w.bits = (self.w.bits & !(0x01 << 7)) | ((value as u32 & 0x01) << 7);
         self.w
     }
 }
-#[doc = "Reader of field `NRV0`"]
-pub type NRV0_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `NRV0`"]
+#[doc = "Field `NRV0` reader - Non-Recoverable State 0 Output Value"]
+pub struct NRV0_R(crate::FieldReader<bool, bool>);
+impl NRV0_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        NRV0_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for NRV0_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `NRV0` writer - Non-Recoverable State 0 Output Value"]
 pub struct NRV0_W<'a> {
     w: &'a mut W,
 }
@@ -222,13 +363,26 @@ impl<'a> NRV0_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 8)) | (((value as u32) & 0x01) << 8);
+        self.w.bits = (self.w.bits & !(0x01 << 8)) | ((value as u32 & 0x01) << 8);
         self.w
     }
 }
-#[doc = "Reader of field `NRV1`"]
-pub type NRV1_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `NRV1`"]
+#[doc = "Field `NRV1` reader - Non-Recoverable State 1 Output Value"]
+pub struct NRV1_R(crate::FieldReader<bool, bool>);
+impl NRV1_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        NRV1_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for NRV1_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `NRV1` writer - Non-Recoverable State 1 Output Value"]
 pub struct NRV1_W<'a> {
     w: &'a mut W,
 }
@@ -246,13 +400,26 @@ impl<'a> NRV1_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 9)) | (((value as u32) & 0x01) << 9);
+        self.w.bits = (self.w.bits & !(0x01 << 9)) | ((value as u32 & 0x01) << 9);
         self.w
     }
 }
-#[doc = "Reader of field `NRV2`"]
-pub type NRV2_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `NRV2`"]
+#[doc = "Field `NRV2` reader - Non-Recoverable State 2 Output Value"]
+pub struct NRV2_R(crate::FieldReader<bool, bool>);
+impl NRV2_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        NRV2_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for NRV2_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `NRV2` writer - Non-Recoverable State 2 Output Value"]
 pub struct NRV2_W<'a> {
     w: &'a mut W,
 }
@@ -270,13 +437,26 @@ impl<'a> NRV2_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 10)) | (((value as u32) & 0x01) << 10);
+        self.w.bits = (self.w.bits & !(0x01 << 10)) | ((value as u32 & 0x01) << 10);
         self.w
     }
 }
-#[doc = "Reader of field `NRV3`"]
-pub type NRV3_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `NRV3`"]
+#[doc = "Field `NRV3` reader - Non-Recoverable State 3 Output Value"]
+pub struct NRV3_R(crate::FieldReader<bool, bool>);
+impl NRV3_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        NRV3_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for NRV3_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `NRV3` writer - Non-Recoverable State 3 Output Value"]
 pub struct NRV3_W<'a> {
     w: &'a mut W,
 }
@@ -294,13 +474,26 @@ impl<'a> NRV3_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 11)) | (((value as u32) & 0x01) << 11);
+        self.w.bits = (self.w.bits & !(0x01 << 11)) | ((value as u32 & 0x01) << 11);
         self.w
     }
 }
-#[doc = "Reader of field `NRV4`"]
-pub type NRV4_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `NRV4`"]
+#[doc = "Field `NRV4` reader - Non-Recoverable State 4 Output Value"]
+pub struct NRV4_R(crate::FieldReader<bool, bool>);
+impl NRV4_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        NRV4_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for NRV4_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `NRV4` writer - Non-Recoverable State 4 Output Value"]
 pub struct NRV4_W<'a> {
     w: &'a mut W,
 }
@@ -318,13 +511,26 @@ impl<'a> NRV4_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 12)) | (((value as u32) & 0x01) << 12);
+        self.w.bits = (self.w.bits & !(0x01 << 12)) | ((value as u32 & 0x01) << 12);
         self.w
     }
 }
-#[doc = "Reader of field `NRV5`"]
-pub type NRV5_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `NRV5`"]
+#[doc = "Field `NRV5` reader - Non-Recoverable State 5 Output Value"]
+pub struct NRV5_R(crate::FieldReader<bool, bool>);
+impl NRV5_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        NRV5_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for NRV5_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `NRV5` writer - Non-Recoverable State 5 Output Value"]
 pub struct NRV5_W<'a> {
     w: &'a mut W,
 }
@@ -342,13 +548,26 @@ impl<'a> NRV5_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 13)) | (((value as u32) & 0x01) << 13);
+        self.w.bits = (self.w.bits & !(0x01 << 13)) | ((value as u32 & 0x01) << 13);
         self.w
     }
 }
-#[doc = "Reader of field `NRV6`"]
-pub type NRV6_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `NRV6`"]
+#[doc = "Field `NRV6` reader - Non-Recoverable State 6 Output Value"]
+pub struct NRV6_R(crate::FieldReader<bool, bool>);
+impl NRV6_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        NRV6_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for NRV6_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `NRV6` writer - Non-Recoverable State 6 Output Value"]
 pub struct NRV6_W<'a> {
     w: &'a mut W,
 }
@@ -366,13 +585,26 @@ impl<'a> NRV6_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 14)) | (((value as u32) & 0x01) << 14);
+        self.w.bits = (self.w.bits & !(0x01 << 14)) | ((value as u32 & 0x01) << 14);
         self.w
     }
 }
-#[doc = "Reader of field `NRV7`"]
-pub type NRV7_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `NRV7`"]
+#[doc = "Field `NRV7` reader - Non-Recoverable State 7 Output Value"]
+pub struct NRV7_R(crate::FieldReader<bool, bool>);
+impl NRV7_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        NRV7_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for NRV7_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `NRV7` writer - Non-Recoverable State 7 Output Value"]
 pub struct NRV7_W<'a> {
     w: &'a mut W,
 }
@@ -390,13 +622,26 @@ impl<'a> NRV7_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 15)) | (((value as u32) & 0x01) << 15);
+        self.w.bits = (self.w.bits & !(0x01 << 15)) | ((value as u32 & 0x01) << 15);
         self.w
     }
 }
-#[doc = "Reader of field `INVEN0`"]
-pub type INVEN0_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `INVEN0`"]
+#[doc = "Field `INVEN0` reader - Output Waveform 0 Inversion"]
+pub struct INVEN0_R(crate::FieldReader<bool, bool>);
+impl INVEN0_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        INVEN0_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for INVEN0_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `INVEN0` writer - Output Waveform 0 Inversion"]
 pub struct INVEN0_W<'a> {
     w: &'a mut W,
 }
@@ -414,13 +659,26 @@ impl<'a> INVEN0_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 16)) | (((value as u32) & 0x01) << 16);
+        self.w.bits = (self.w.bits & !(0x01 << 16)) | ((value as u32 & 0x01) << 16);
         self.w
     }
 }
-#[doc = "Reader of field `INVEN1`"]
-pub type INVEN1_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `INVEN1`"]
+#[doc = "Field `INVEN1` reader - Output Waveform 1 Inversion"]
+pub struct INVEN1_R(crate::FieldReader<bool, bool>);
+impl INVEN1_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        INVEN1_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for INVEN1_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `INVEN1` writer - Output Waveform 1 Inversion"]
 pub struct INVEN1_W<'a> {
     w: &'a mut W,
 }
@@ -438,13 +696,26 @@ impl<'a> INVEN1_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 17)) | (((value as u32) & 0x01) << 17);
+        self.w.bits = (self.w.bits & !(0x01 << 17)) | ((value as u32 & 0x01) << 17);
         self.w
     }
 }
-#[doc = "Reader of field `INVEN2`"]
-pub type INVEN2_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `INVEN2`"]
+#[doc = "Field `INVEN2` reader - Output Waveform 2 Inversion"]
+pub struct INVEN2_R(crate::FieldReader<bool, bool>);
+impl INVEN2_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        INVEN2_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for INVEN2_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `INVEN2` writer - Output Waveform 2 Inversion"]
 pub struct INVEN2_W<'a> {
     w: &'a mut W,
 }
@@ -462,13 +733,26 @@ impl<'a> INVEN2_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 18)) | (((value as u32) & 0x01) << 18);
+        self.w.bits = (self.w.bits & !(0x01 << 18)) | ((value as u32 & 0x01) << 18);
         self.w
     }
 }
-#[doc = "Reader of field `INVEN3`"]
-pub type INVEN3_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `INVEN3`"]
+#[doc = "Field `INVEN3` reader - Output Waveform 3 Inversion"]
+pub struct INVEN3_R(crate::FieldReader<bool, bool>);
+impl INVEN3_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        INVEN3_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for INVEN3_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `INVEN3` writer - Output Waveform 3 Inversion"]
 pub struct INVEN3_W<'a> {
     w: &'a mut W,
 }
@@ -486,13 +770,26 @@ impl<'a> INVEN3_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 19)) | (((value as u32) & 0x01) << 19);
+        self.w.bits = (self.w.bits & !(0x01 << 19)) | ((value as u32 & 0x01) << 19);
         self.w
     }
 }
-#[doc = "Reader of field `INVEN4`"]
-pub type INVEN4_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `INVEN4`"]
+#[doc = "Field `INVEN4` reader - Output Waveform 4 Inversion"]
+pub struct INVEN4_R(crate::FieldReader<bool, bool>);
+impl INVEN4_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        INVEN4_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for INVEN4_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `INVEN4` writer - Output Waveform 4 Inversion"]
 pub struct INVEN4_W<'a> {
     w: &'a mut W,
 }
@@ -510,13 +807,26 @@ impl<'a> INVEN4_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 20)) | (((value as u32) & 0x01) << 20);
+        self.w.bits = (self.w.bits & !(0x01 << 20)) | ((value as u32 & 0x01) << 20);
         self.w
     }
 }
-#[doc = "Reader of field `INVEN5`"]
-pub type INVEN5_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `INVEN5`"]
+#[doc = "Field `INVEN5` reader - Output Waveform 5 Inversion"]
+pub struct INVEN5_R(crate::FieldReader<bool, bool>);
+impl INVEN5_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        INVEN5_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for INVEN5_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `INVEN5` writer - Output Waveform 5 Inversion"]
 pub struct INVEN5_W<'a> {
     w: &'a mut W,
 }
@@ -534,13 +844,26 @@ impl<'a> INVEN5_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 21)) | (((value as u32) & 0x01) << 21);
+        self.w.bits = (self.w.bits & !(0x01 << 21)) | ((value as u32 & 0x01) << 21);
         self.w
     }
 }
-#[doc = "Reader of field `INVEN6`"]
-pub type INVEN6_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `INVEN6`"]
+#[doc = "Field `INVEN6` reader - Output Waveform 6 Inversion"]
+pub struct INVEN6_R(crate::FieldReader<bool, bool>);
+impl INVEN6_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        INVEN6_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for INVEN6_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `INVEN6` writer - Output Waveform 6 Inversion"]
 pub struct INVEN6_W<'a> {
     w: &'a mut W,
 }
@@ -558,13 +881,26 @@ impl<'a> INVEN6_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 22)) | (((value as u32) & 0x01) << 22);
+        self.w.bits = (self.w.bits & !(0x01 << 22)) | ((value as u32 & 0x01) << 22);
         self.w
     }
 }
-#[doc = "Reader of field `INVEN7`"]
-pub type INVEN7_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `INVEN7`"]
+#[doc = "Field `INVEN7` reader - Output Waveform 7 Inversion"]
+pub struct INVEN7_R(crate::FieldReader<bool, bool>);
+impl INVEN7_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        INVEN7_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for INVEN7_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `INVEN7` writer - Output Waveform 7 Inversion"]
 pub struct INVEN7_W<'a> {
     w: &'a mut W,
 }
@@ -582,13 +918,26 @@ impl<'a> INVEN7_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 23)) | (((value as u32) & 0x01) << 23);
+        self.w.bits = (self.w.bits & !(0x01 << 23)) | ((value as u32 & 0x01) << 23);
         self.w
     }
 }
-#[doc = "Reader of field `FILTERVAL0`"]
-pub type FILTERVAL0_R = crate::R<u8, u8>;
-#[doc = "Write proxy for field `FILTERVAL0`"]
+#[doc = "Field `FILTERVAL0` reader - Non-Recoverable Fault Input 0 Filter Value"]
+pub struct FILTERVAL0_R(crate::FieldReader<u8, u8>);
+impl FILTERVAL0_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: u8) -> Self {
+        FILTERVAL0_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for FILTERVAL0_R {
+    type Target = crate::FieldReader<u8, u8>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `FILTERVAL0` writer - Non-Recoverable Fault Input 0 Filter Value"]
 pub struct FILTERVAL0_W<'a> {
     w: &'a mut W,
 }
@@ -596,13 +945,26 @@ impl<'a> FILTERVAL0_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x0f << 24)) | (((value as u32) & 0x0f) << 24);
+        self.w.bits = (self.w.bits & !(0x0f << 24)) | ((value as u32 & 0x0f) << 24);
         self.w
     }
 }
-#[doc = "Reader of field `FILTERVAL1`"]
-pub type FILTERVAL1_R = crate::R<u8, u8>;
-#[doc = "Write proxy for field `FILTERVAL1`"]
+#[doc = "Field `FILTERVAL1` reader - Non-Recoverable Fault Input 1 Filter Value"]
+pub struct FILTERVAL1_R(crate::FieldReader<u8, u8>);
+impl FILTERVAL1_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: u8) -> Self {
+        FILTERVAL1_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for FILTERVAL1_R {
+    type Target = crate::FieldReader<u8, u8>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `FILTERVAL1` writer - Non-Recoverable Fault Input 1 Filter Value"]
 pub struct FILTERVAL1_W<'a> {
     w: &'a mut W,
 }
@@ -610,7 +972,7 @@ impl<'a> FILTERVAL1_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x0f << 28)) | (((value as u32) & 0x0f) << 28);
+        self.w.bits = (self.w.bits & !(0x0f << 28)) | ((value as u32 & 0x0f) << 28);
         self.w
     }
 }
@@ -877,4 +1239,30 @@ impl W {
     pub fn filterval1(&mut self) -> FILTERVAL1_W {
         FILTERVAL1_W { w: self }
     }
+    #[doc = "Writes raw bits to the register."]
+    #[inline(always)]
+    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
+        self.0.bits(bits);
+        self
+    }
+}
+#[doc = "Driver Control\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [drvctrl](index.html) module"]
+pub struct DRVCTRL_SPEC;
+impl crate::RegisterSpec for DRVCTRL_SPEC {
+    type Ux = u32;
+}
+#[doc = "`read()` method returns [drvctrl::R](R) reader structure"]
+impl crate::Readable for DRVCTRL_SPEC {
+    type Reader = R;
+}
+#[doc = "`write(|w| ..)` method takes [drvctrl::W](W) writer structure"]
+impl crate::Writable for DRVCTRL_SPEC {
+    type Writer = W;
+}
+#[doc = "`reset()` method sets DRVCTRL to value 0"]
+impl crate::Resettable for DRVCTRL_SPEC {
+    #[inline(always)]
+    fn reset_value() -> Self::Ux {
+        0
+    }
 }
